
/*
	Script 2 Medical schema and tables
*/

use CassandraTest;
go

CREATE TABLE [Medical].[SurgeryCenter]
(
	[SurgeryCenterName] [sysname] NOT NULL PRIMARY KEY
);
INSERT INTO Medical.SurgeryCenter(SurgeryCenterName) VALUES( 'Briggs' );

select * from Medical.SurgeryCenter;

	/*-----*/

CREATE TABLE [Medical].[Doctor](
	[DoctorName] [sysname] NOT NULL PRIMARY KEY
);
INSERT INTO Medical.Doctor(DoctorName) VALUES ('Jimmy Connors'), ('Patrick McEnroe');
select * from Medical.Doctor;

	/*-----*/

CREATE TABLE [Medical].[Patient](
	[PatientName] [sysname] NOT NULL PRIMARY KEY
);
INSERT INTO Medical.Patient(PatientName) VALUES ('Anna'), ('Byron'), ('Carol');
select * from Medical.Patient;

	/*-----*/

CREATE TABLE [Medical].[Surgery](
	[SurgeryCenter] [sysname] NOT NULL,
	[LeadSurgeon] [sysname] NOT NULL,
	[Patient] [sysname] NOT NULL,
	[StartDateTime] [datetime2](7) NOT NULL,
	[SurgeryID] [uniqueidentifier] NOT NULL,
 CONSTRAINT [PK_surgery__surgeon_time] PRIMARY KEY CLUSTERED 
(
	[LeadSurgeon] ASC,
	[StartDateTime] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY],
 CONSTRAINT [UQ_surgery__patient_time] UNIQUE NONCLUSTERED 
(
	[Patient] ASC,
	[StartDateTime] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY],
 CONSTRAINT [UQ_surgery__surgeryID] UNIQUE NONCLUSTERED 
(
	[SurgeryID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [Medical].[Surgery]  WITH CHECK ADD FOREIGN KEY([LeadSurgeon])
REFERENCES [Medical].[Doctor] ([DoctorName])
GO

ALTER TABLE [Medical].[Surgery]  WITH CHECK ADD FOREIGN KEY([Patient])
REFERENCES [Medical].[Patient] ([PatientName])
GO

ALTER TABLE [Medical].[Surgery]  WITH CHECK ADD FOREIGN KEY([SurgeryCenter])
REFERENCES [Medical].[SurgeryCenter] ([SurgeryCenterName])
GO

INSERT INTO Medical.Surgery(SurgeryCenter, LeadSurgeon, Patient, StartDateTime, SurgeryID)
VALUES
	('Briggs', 'Jimmy Connors', 'Anna', '2020-01-16 09:45:00', 'EBAEB2B5-5932-40AD-BEAF-B41B09D1C640'),
	('Briggs', 'Jimmy Connors', 'Carol', '2020-01-15 10:15:00', '9B7F322F-D511-4A4E-92C8-A1291EBB9266'),
	('Briggs', 'Patrick McEnroe', 'Byron', '2020-01-13 08:00:00', 'F7707398-74DD-425C-8F6F-6825964216C2');

select * from Medical.Surgery;

	/*-----*/

CREATE TABLE [Medical].[SurgeryProcedure](
	[SurgeryID] [uniqueidentifier] NOT NULL,
	[SurgicalProcedure] [int] NOT NULL,
PRIMARY KEY CLUSTERED 
(
	[SurgeryID] ASC,
	[SurgicalProcedure] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [Medical].[SurgeryProcedure]  WITH CHECK ADD FOREIGN KEY([SurgeryID])
REFERENCES [Medical].[Surgery] ([SurgeryID])
ON DELETE CASCADE
GO

INSERT INTO Medical.SurgeryProcedure( SurgeryID, SurgicalProcedure ) 
VALUES
	( 'EBAEB2B5-5932-40AD-BEAF-B41B09D1C640', 60004 ),
	( '9B7F322F-D511-4A4E-92C8-A1291EBB9266', 60000 ),
	( '9B7F322F-D511-4A4E-92C8-A1291EBB9266', 61005 ),
	( 'F7707398-74DD-425C-8F6F-6825964216C2', 27763 )

select * from Medical.SurgeryProcedure;
